@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright (c) 2012 Mikkel Schubert <MSchubert@snm.ku.dk>
+# Copyright (c) 2012 Mikkel Schubert <MikkelSch@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,3 +21,7 @@
 # SOFTWARE.
 #
 import paths
+
+__all__ = [
+    'paths',
+]
\ No newline at end of file
