@@ -5,3 +5,14 @@ from sample import Sample
 from prefix import Prefix
 from target import Target
 from statistics import add_statistics_nodes
+
+
+__all__ = [
+    'Reads',
+    'Lane',
+    'Library',
+    'Sample',
+    'Prefix',
+    'Target',
+    'add_statistics_nodes',
+]
\ No newline at end of file
