@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright (c) 2012 Mikkel Schubert <MSchubert@snm.ku.dk>
+# Copyright (c) 2012 Mikkel Schubert <MikkelSch@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -20,12 +20,13 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 #
+import collections
+import json
+import math
+import numbers
 import os
 import re
 import sys
-import math
-import numbers
-import collections
 
 from paleomix.node import Node, NodeError
 from paleomix.common.utilities import set_in, get_in
@@ -40,7 +41,6 @@ import paleomix.common.text as text
 _PE_READS = frozenset(("Paired", "Singleton",
                        "Collapsed", "CollapsedTruncated"))
 _SE_READS = frozenset(("Single",))
-_BAMS     = frozenset(())
 
 
 class SummaryTableNode(Node):
@@ -61,19 +61,31 @@ class SummaryTableNode(Node):
             for sample in prefix.samples:
                 for library in sample.libraries:
                     for lane in library.lanes:
-                        if lane.reads:
-                            if lane.reads.stats:
-                                value = lane.reads.stats
-                                input_files.add(value)
-                            elif set(lane.reads.files) & _PE_READS:
-                                value = _PE_READS
-                            elif set(lane.reads.files) & _SE_READS:
-                                value = _SE_READS
+                        filename = None
+                        filetype = None
+
+                        if lane.reads.stats:
+                            filetype = 'Raw'
+                            filename = lane.reads.stats
+                        elif lane.reads.validation:
+                            filename = lane.reads.validation
+                            fileset = set(lane.reads.files)
+
+                            if fileset & _PE_READS and fileset & _SE_READS:
+                                filetype = '*'
+                            elif fileset & _PE_READS:
+                                filetype = 'PE'
+                            elif fileset & _SE_READS:
+                                filetype = 'SE'
                             else:
-                                assert False
+                                assert False, lane.reads.files
+                                continue
+
+                            input_files.add(filename)
                         else:
-                            value = _BAMS
-                        self._in_raw_read[(sample.name, library.name, lane.name)] = value
+                            assert False
+
+                        self._in_raw_read[(sample.name, library.name, lane.name)] = (filetype, filename)
 
         Node.__init__(self,
                       description  = "<Summary: %s>" % self._output_file,
@@ -133,7 +145,12 @@ class SummaryTableNode(Node):
 
 
     def _write_tables(self, out, genomes):
-        rows = [["Target", "Sample", "Library", "Measure", "Value", "# Description"]]
+        for row in self._build_tables(genomes):
+            out.write("%s\n" % '\t'.join(map(str, row)))
+
+    def _build_tables(self, genomes):
+        yield ["Target", "Sample", "Library", "Measure", "Value", "# Description"]
+
         for (target, samples) in sorted(self._read_tables(self._prefixes, genomes).iteritems()):
             for (sample, libraries) in sorted(samples.iteritems()):
                 for (library, prefixes) in sorted(libraries.iteritems()):
@@ -146,13 +163,9 @@ class SummaryTableNode(Node):
                         for (key, (value, comment)) in sorted(table.iteritems(), key = _measure_ordering):
                             if isinstance(value, numbers.Number) and math.isnan(value):
                                 value = "NA"
-                            rows.append((target, sample, library, key, value, comment))
-                        rows.append("")
-                    rows.append("")
-
-        for line in text.padded_table(rows):
-            out.write("%s\n" % line)
-
+                            yield (target, sample, library, key, value, comment)
+                        yield ""
+                    yield ""
 
     def _read_tables(self, prefixes, genomes):
         table = {}
@@ -190,19 +203,20 @@ class SummaryTableNode(Node):
 
                 for (numerator, denominator, measure, comment) in fractions:
                     if (numerator in subtable) and (denominator in subtable):
-                        value = float(subtable[numerator][0]) / subtable[denominator][0]
+                        value = subtable[numerator][0] / float(subtable[denominator][0] or "NaN")
                         subtable[measure] = (value, comment)
             else:
                 total_hits  = subtable["hits_raw(%s)" % tblname][0]
                 total_nts   = subtable["hits_unique_nts(%s)" % tblname][0]
                 total_uniq  = subtable["hits_unique(%s)" % tblname][0]
-                total_reads = subtables.get("reads",{}).get("seq_retained_reads", (float("NAN"),))[0]
+                total_reads = subtables.get("reads",{}).get("seq_retained_reads", (0,))[0]
+                genome_size = genomes[tblname]["Size"]
 
-                subtable["hits_raw_frac(%s)" % tblname] = (total_hits / float(total_reads), "# Total number of hits vs. total number of reads retained")
-                subtable["hits_unique_frac(%s)" % tblname] = (total_uniq / float(total_reads), "# Total number of unique hits vs. total number of reads retained")
-                subtable["hits_clonality(%s)" % tblname] = (1 - total_uniq / (float(total_hits) or float("NaN")), "# Fraction of hits that were PCR duplicates")
-                subtable["hits_length(%s)" % tblname] = (total_nts / (float(total_uniq) or float("NaN")), "# Average number of aligned bases per unique hit")
-                subtable["hits_coverage(%s)" % tblname] = (total_nts / float(genomes[tblname]["Size"]), "# Estimated coverage from unique hits")
+                subtable["hits_raw_frac(%s)" % tblname] = (total_hits / float(total_reads or "NaN"), "# Total number of hits vs. total number of reads retained")
+                subtable["hits_unique_frac(%s)" % tblname] = (total_uniq / float(total_reads or "NaN"), "# Total number of unique hits vs. total number of reads retained")
+                subtable["hits_clonality(%s)" % tblname] = (1 - total_uniq / float(total_hits or "NaN"), "# Fraction of hits that were PCR duplicates")
+                subtable["hits_length(%s)" % tblname] = (total_nts / float(total_uniq or "NaN"), "# Average number of aligned bases per unique hit")
+                subtable["hits_coverage(%s)" % tblname] = (total_nts / float(genome_size or "NaN"), "# Estimated coverage from unique hits")
 
         return subtables
 
@@ -234,11 +248,11 @@ class SummaryTableNode(Node):
 
 
     def _read_reads_settings(self, table):
-        for ((sample, library, barcode), filename) in self._in_raw_read.iteritems():
+        for ((sample, library, barcode), (filetype, filename)) in self._in_raw_read.iteritems():
             key = (self._target, sample, library, "reads", barcode)
-            set_in(table, key, self._stat_read_settings(filename))
+            set_in(table, key, self._stat_read_settings(filetype, filename))
 
-        for (target, samples) in table.iteritems():
+        for (_, samples) in table.iteritems():
             for (sample, libraries) in samples.iteritems():
                 for (library, prefixes) in libraries.iteritems():
                     prefixes["reads"] = self._merge_tables(prefixes["reads"].values())
@@ -303,38 +317,33 @@ class SummaryTableNode(Node):
 
 
     @classmethod
-    def _stat_read_settings(cls, filename):
-        if isinstance(filename, frozenset):
-            if (filename == _SE_READS):
-                return {
-                    "lib_type"           : ("SE", "# SE, PE, or * (for both)"),
-                    "seq_reads_se"       : (float("nan"),  "# Total number of single-ended reads"),
-                    "seq_trash_se"       : (float("nan"),  "# Total number of trashed reads"),
-                    "seq_retained_nts"   : (float("nan"),  "# Total number of NTs in retained reads"),
-                    "seq_retained_reads" : (float("nan"),  "# Total number of retained reads"),
-                    }
-            elif (filename == _PE_READS):
-                return {
-                    "lib_type"            : ("PE", "# SE, PE, or * (for both)"),
-                    "seq_reads_pairs"     : (float("nan"), "# Total number of reads"),
-                    "seq_trash_pe_1"      : (float("nan"), "# Total number of reads"),
-                    "seq_trash_pe_2"      : (float("nan"), "# Total number of reads"),
-                    "seq_retained_nts"    : (float("nan"), "# Total number of NTs in retained reads"),
-                    "seq_retained_reads"  : (float("nan"), "# Total number of retained reads"),
-                    "seq_collapsed"       : (float("nan"), "# Total number of pairs collapsed into one read"),
-                    }
-            else:
-                return {
-                    "lib_type"           : ("*", "# SE, PE, or * (for both)"),
-                    "seq_reads_se"       : (float("nan"),  "# Total number of single-ended reads"),
-                    "seq_trash_se"       : (float("nan"),  "# Total number of trashed reads"),
-                    "seq_reads_pairs"    : (float("nan"), "# Total number of reads"),
-                    "seq_trash_pe_1"     : (float("nan"), "# Total number of reads"),
-                    "seq_trash_pe_2"     : (float("nan"), "# Total number of reads"),
-                    "seq_retained_nts"   : (float("nan"),  "# Total number of NTs in retained reads"),
-                    "seq_retained_reads" : (float("nan"),  "# Total number of retained reads"),
-                    "seq_collapsed"      : (float("nan"), "# Total number of pairs collapsed into one read"),
-                    }
+    def _stat_read_settings(cls, filetype, filename):
+        assert filetype in ('Raw', 'SE', 'PE', '*', 'BAM'), filetype
+
+        if filetype != 'Raw':
+            stats = {
+                "lib_type": (filetype, "# SE, PE, or * (for both)"),
+                "seq_retained_nts": [float("nan"), "# Total number of NTs in retained reads"],
+                "seq_retained_reads": [float("nan"), "# Total number of retained reads"],
+            }
+
+            if filetype in ('SE', '*'):
+                stats["seq_reads_se"] = [float("nan"),  "# Total number of single-ended reads"]
+                stats["seq_trash_se"] = [float("nan"),  "# Total number of trashed reads"]
+
+            if filetype in ('PE', '*'):
+                stats["seq_reads_pairs"] = [float("nan"), "# Total number of reads"]
+                stats["seq_trash_pe_1"] = [float("nan"), "# Total number of reads"]
+                stats["seq_trash_pe_2"] = [float("nan"), "# Total number of reads"]
+                stats["seq_collapsed"] = [float("nan"), "# Total number of pairs collapsed into one read"]
+
+            if filename is not None:
+                with open(filename) as handle:
+                    for key, value in json.load(handle).items():
+                        if key in stats:
+                            stats[key][0] = int(value)
+
+            return stats
 
         with open(filename) as settings_file:
             settings = settings_file.read()
