@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright (c) 2013 Mikkel Schubert <MSchubert@snm.ku.dk>
+# Copyright (c) 2013 Mikkel Schubert <MikkelSch@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -1789,7 +1789,7 @@ def test_read_makefile__not_a_yaml_file():
     assert_raises(MakefileError, read_makefile, fpath, {})
 
 
-def test_read_makefile__missing_simple_file():
+def test_read_makefile__simple_file():
     specs = {"Defaults": {"First": IsFloat, "Second": IsStr}}
     expected = {
         "Makefile": {"Defaults": {"First": 1e-4,
@@ -1797,10 +1797,13 @@ def test_read_makefile__missing_simple_file():
         "Statistics": {
             "Filename": test_file("simple.yaml"),
             "Hash": "563a2052b67dcde9f193fbe8d51fa2b6f0806505",
-            "MTime": "2005-07-07 08:50:00",
         }
     }
     result = read_makefile(test_file("simple.yaml"), specs)
+
+    # MTime is troublesome, and will be removed later anyway, so don't bother
+    result.get('Statistics', {}).pop('MTime', None)
+
     assert_equal(expected, result)
 
 
