@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright (c) 2012 Mikkel Schubert <MSchubert@snm.ku.dk>
+# Copyright (c) 2012 Mikkel Schubert <MikkelSch@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -494,7 +494,7 @@ def test_requirementobj__version__command_not_found():
 
 
 def test_requirementobj__version__command_not_executable():
-    obj = versions.RequirementObj(call=("./README.md",),
+    obj = versions.RequirementObj(call=("./README.rst",),
                                   search=r"v(\d+)\.(\d+)",
                                   checks=versions.Any())
 
@@ -503,7 +503,7 @@ def test_requirementobj__version__command_not_executable():
         assert False  # pragma: no coverage
     except versions.VersionRequirementError as error:
         # Should include OSError message
-        assert_in("Permission denied", str(error))
+        assert_in("OSError", str(error))
 
 
 def test_requirementobj__version__return_code_is_ignored():
